@@ -1,4 +1,4 @@
-# last modified 2013-01-10 by J. Fox
+# last modified 2013-09-17 by J. Fox
 
 #survregModel <-
 #	function(){
@@ -194,7 +194,7 @@
 survregModel <- function(){
 	## notes: robust=TRUE causes errors 
 	## counting-process form of Surv() doesn't seem to work
-	require(survival)
+	# require(survival)
 	defaults <- list(time1=NULL, time2=NULL, event=NULL, strata=NULL, cluster=NULL, survtype="default", robust="default", dist="weibull", subset=NULL)
 	dialog.values <- getDialog("survregModel", defaults)
 	if (!activeDataSetP()) return()
